﻿#!/usr/bin/python
# -*- coding: utf-8 -*-

import os

def DebugLog(msg):
   if os.environ.has_key('DEBUG'):
      print msg

def DebugFile(msg):
   if os.environ.has_key('DEBUG'):
      f = open('debug.log', 'a')
      f.write(str(msg)+"\n")
      f.close()
